@@ -10,7 +10,7 @@ setlocale(LC_CTYPE, "pt_PT");
 use locale;
 
 use base 'Exporter';
-our @EXPORT_OK = (qw.onethat verif nlgrep setstopwords
+our @EXPORT_OK = (qw.allthat onethat verif nlgrep setstopwords
                      onethatverif any2str hash2str isguess.);
 
 our %EXPORT_TAGS = (basic => [qw.onethat verif onethatverif
@@ -32,7 +32,7 @@ Lingua::Jspell - Perl interface to the Jspell morphological analyser.
 
 =cut
 
-our $VERSION = '1.96';
+our $VERSION = '1.97';
 our $JSPELL;
 our $JSPELLLIB;
 our $MODE = { nm => "af", flags => 0 };
@@ -500,6 +500,24 @@ sub onethat {
     return () ;
 }
 
+
+=head2 allthat
+
+Returns all Feature Structures from the supplied list that
+verifies the used Feature Structure Pattern.
+
+  @analyses = allthat( { CAT=>'adj' }, @features);
+
+  @analyses = allthat( { CAT=>'adj' }, $pt->fea("espanhol"));
+
+=cut
+
+sub allthat {
+    my ($a, @b) = @_;
+    return grep {verif($a, $_)} @b;
+}
+
+
 =head2 verif
 
 Returns a true value if the second Feature Structure verifies the
